@@ -10,8 +10,7 @@ from __future__ import annotations
 
 import ast
 from contextlib import suppress
-from itertools import zip_longest
-from typing import TYPE_CHECKING, Any, Iterable
+from typing import TYPE_CHECKING, Any
 
 from griffe.agents.nodes import (
     ast_children,
@@ -20,34 +19,28 @@ from griffe.agents.nodes import (
     get_docstring,
     get_instance_names,
     get_names,
+    get_parameters,
     relative_to_absolute,
     safe_get__all__,
+)
+from griffe.collections import LinesCollection, ModulesCollection
+from griffe.dataclasses import Alias, Attribute, Class, Decorator, Docstring, Function, Module, Parameter, Parameters
+from griffe.enumerations import Kind
+from griffe.exceptions import AliasResolutionError, CyclicAliasError, LastNodeError
+from griffe.expressions import (
+    Expr,
+    ExprName,
     safe_get_annotation,
     safe_get_base_class,
     safe_get_condition,
+    safe_get_expression,
 )
-from griffe.collections import LinesCollection, ModulesCollection
-from griffe.dataclasses import (
-    Alias,
-    Attribute,
-    Class,
-    Decorator,
-    Docstring,
-    Function,
-    Kind,
-    Module,
-    Parameter,
-    ParameterKind,
-    Parameters,
-)
-from griffe.exceptions import AliasResolutionError, CyclicAliasError, LastNodeError
-from griffe.expressions import Expr, safe_get_expression
-from griffe.extensions import Extensions
+from griffe.extensions.base import Extensions, load_extensions
 
 if TYPE_CHECKING:
     from pathlib import Path
 
-    from griffe.docstrings.parsers import Parser
+    from griffe.enumerations import Parser
 
 
 builtin_decorators = {
@@ -99,7 +92,7 @@ def visit(
         module_name,
         filepath,
         code,
-        extensions or Extensions(),
+        extensions or load_extensions(),
         parent,
         docstring_parser=docstring_parser,
         docstring_options=docstring_options,
@@ -366,78 +359,19 @@ class Visitor:
             return
 
         # handle parameters
-        parameters = Parameters()
-        annotation: str | Expr | None
-
-        posonlyargs = node.args.posonlyargs
-
-        # TODO: probably some optimizations to do here
-        args_kinds_defaults: Iterable = reversed(
-            (
-                *zip_longest(
-                    reversed(
-                        (
-                            *zip_longest(
-                                posonlyargs,
-                                [],
-                                fillvalue=ParameterKind.positional_only,
-                            ),
-                            *zip_longest(node.args.args, [], fillvalue=ParameterKind.positional_or_keyword),
-                        ),
-                    ),
-                    reversed(node.args.defaults),
-                    fillvalue=None,
-                ),
-            ),
-        )
-        arg: ast.arg
-        kind: ParameterKind
-        arg_default: ast.AST | None
-        for (arg, kind), arg_default in args_kinds_defaults:
-            annotation = safe_get_annotation(arg.annotation, parent=self.current)
-            default = safe_get_expression(arg_default, parent=self.current, parse_strings=False)
-            parameters.add(Parameter(arg.arg, annotation=annotation, kind=kind, default=default))
-
-        if node.args.vararg:
-            annotation = safe_get_annotation(node.args.vararg.annotation, parent=self.current)
-            parameters.add(
+        parameters = Parameters(
+            *[
                 Parameter(
-                    node.args.vararg.arg,
-                    annotation=annotation,
-                    kind=ParameterKind.var_positional,
-                    default="()",
-                ),
-            )
-
-        # TODO: probably some optimizations to do here
-        kwargs_defaults: Iterable = reversed(
-            (
-                *zip_longest(
-                    reversed(node.args.kwonlyargs),
-                    reversed(node.args.kw_defaults),
-                    fillvalue=None,
-                ),
-            ),
+                    name,
+                    kind=kind,
+                    annotation=safe_get_annotation(annotation, parent=self.current),
+                    default=default
+                    if isinstance(default, str)
+                    else safe_get_expression(default, parent=self.current, parse_strings=False),
+                )
+                for name, annotation, kind, default in get_parameters(node.args)
+            ],
         )
-        kwarg: ast.arg
-        kwarg_default: ast.AST | None
-        for kwarg, kwarg_default in kwargs_defaults:
-            annotation = safe_get_annotation(kwarg.annotation, parent=self.current)
-            default = safe_get_expression(kwarg_default, parent=self.current, parse_strings=False)
-            parameters.add(
-                Parameter(kwarg.arg, annotation=annotation, kind=ParameterKind.keyword_only, default=default),
-            )
-
-        if node.args.kwarg:
-            annotation = safe_get_annotation(node.args.kwarg.annotation, parent=self.current)
-            parameters.add(
-                Parameter(
-                    node.args.kwarg.arg,
-                    annotation=annotation,
-                    kind=ParameterKind.var_keyword,
-                    default="{}",
-                ),
-            )
 
         function = Function(
             name=node.name,
@@ -501,7 +435,7 @@ class Visitor:
             node: The node to visit.
         """
         for name in node.names:
-            alias_path = name.name.split(".", 1)[0]
+            alias_path = name.name if name.asname else name.name.split(".", 1)[0]
             alias_name = name.asname or alias_path.split(".", 1)[0]
             self.current.imports[alias_name] = alias_path
             self.current.set_member(
@@ -536,16 +470,20 @@ class Visitor:
             else:
                 alias_name = name.asname or name.name
                 self.current.imports[alias_name] = alias_path
-            self.current.set_member(
-                alias_name,
-                Alias(
+            # Do not create aliases pointing to themselves (it happens with
+            # `from package.current_module import Thing as Thing` or
+            # `from . import thing as thing`).
+            if alias_path != f"{self.current.path}.{alias_name}":
+                self.current.set_member(
                     alias_name,
-                    alias_path,
-                    lineno=node.lineno,
-                    endlineno=node.end_lineno,
-                    runtime=not self.type_guarded,
-                ),
-            )
+                    Alias(
+                        alias_name,
+                        alias_path,
+                        lineno=node.lineno,
+                        endlineno=node.end_lineno,
+                        runtime=not self.type_guarded,
+                    ),
+                )
 
     def handle_attribute(
         self,
@@ -643,7 +581,10 @@ class Visitor:
 
             if name == "__all__":
                 with suppress(AttributeError):
-                    parent.exports = safe_get__all__(node, self.current)  # type: ignore[arg-type]
+                    parent.exports = [
+                        name if isinstance(name, str) else ExprName(name.name, parent=name.parent)
+                        for name in safe_get__all__(node, self.current)  # type: ignore[arg-type]
+                    ]
             self.extensions.call("on_instance", node=node, obj=attribute)
             self.extensions.call("on_attribute_instance", node=node, attr=attribute)
 
@@ -677,7 +618,12 @@ class Visitor:
             )
             if all_augment:
                 # we assume exports is not None at this point
-                self.current.exports.extend(safe_get__all__(node, self.current))  # type: ignore[arg-type,union-attr]
+                self.current.exports.extend(  # type: ignore[union-attr]
+                    [
+                        name if isinstance(name, str) else ExprName(name.name, parent=name.parent)
+                        for name in safe_get__all__(node, self.current)  # type: ignore[arg-type]
+                    ],
+                )
 
     def visit_if(self, node: ast.If) -> None:
         """Visit an "if" node.
