@@ -25,18 +25,18 @@ from typing import IO, TYPE_CHECKING, Any, Callable, Sequence
 import colorama
 
 from griffe import debug
-from griffe.diff import ExplanationStyle, find_breaking_changes
-from griffe.docstrings.parsers import Parser
+from griffe.diff import find_breaking_changes
 from griffe.encoders import JSONEncoder
+from griffe.enumerations import ExplanationStyle, Parser
 from griffe.exceptions import ExtensionError, GitError
 from griffe.extensions.base import load_extensions
-from griffe.git import _get_latest_tag, _get_repo_root, load_git
-from griffe.loader import GriffeLoader, load
+from griffe.git import get_latest_tag, get_repo_root
+from griffe.loader import GriffeLoader, load, load_git
 from griffe.logger import get_logger
 from griffe.stats import _format_stats
 
 if TYPE_CHECKING:
-    from griffe.extensions import Extensions, ExtensionType
+    from griffe.extensions.base import Extensions, ExtensionType
 
 
 DEFAULT_LOG_LEVEL = os.getenv("GRIFFE_LOG_LEVEL", "INFO").upper()
@@ -153,6 +153,13 @@ def get_parser() -> argparse.ArgumentParser:
             type=Path,
             help="Paths to search packages into.",
         )
+        search_options.add_argument(
+            "-y",
+            "--sys-path",
+            dest="append_sys_path",
+            action="store_true",
+            help="Whether to append `sys.path` to search paths specified with `-s`.",
+        )
         loading_options = subparser.add_argument_group(title="Loading options")
         loading_options.add_argument(
             "-B",
@@ -233,13 +240,6 @@ def get_parser() -> argparse.ArgumentParser:
         type=json.loads,
         help="The options for the docstring parser.",
     )
-    dump_options.add_argument(
-        "-y",
-        "--sys-path",
-        dest="append_sys_path",
-        action="store_true",
-        help="Whether to append `sys.path` to search paths specified with `-s`.",
-    )
     dump_options.add_argument(
         "-r",
         "--resolve-aliases",
@@ -401,13 +401,14 @@ def check(
     base_ref: str | None = None,
     extensions: Sequence[str | dict[str, Any] | ExtensionType | type[ExtensionType]] | None = None,
     search_paths: Sequence[str | Path] | None = None,
+    append_sys_path: bool = False,
     find_stubs_package: bool = False,
     allow_inspection: bool = True,
     verbose: bool = False,
     color: bool | None = None,
     style: str | ExplanationStyle | None = None,
 ) -> int:
-    """Load packages data and dump it as JSON.
+    """Check for API breaking changes in two versions of the same package.
 
     Parameters:
         package: The package to load and check.
@@ -416,6 +417,7 @@ def check(
         base_ref: Git reference (commit, branch, tag) to check.
         extensions: The extensions to use.
         search_paths: The paths to search into.
+        append_sys_path: Whether to append the contents of `sys.path` to the search paths.
         allow_inspection: Whether to allow inspecting modules when visiting them is not possible.
         verbose: Use a verbose output.
 
@@ -424,14 +426,16 @@ def check(
     """
     # Prepare options.
     search_paths = list(search_paths) if search_paths else []
+    if append_sys_path:
+        search_paths.extend(sys.path)
 
     try:
-        against = against or _get_latest_tag(package)
+        against = against or get_latest_tag(package)
     except GitError as error:
         print(f"griffe: error: {error}", file=sys.stderr)
         return 2
     against_path = against_path or package
-    repository = _get_repo_root(against_path)
+    repository = get_repo_root(against_path)
 
     try:
         loaded_extensions = load_extensions(extensions or ())
@@ -473,7 +477,7 @@ def check(
 
     colorama.deinit()
     colorama.init(strip=color if color is None else not color)
-    if style is None:  # noqa: SIM108
+    if style is None:
         style = ExplanationStyle.VERBOSE if verbose else ExplanationStyle.ONE_LINE
     else:
         style = ExplanationStyle(style)
