@@ -15,8 +15,8 @@ from textwrap import dedent
 from typing import TYPE_CHECKING, Any, Callable, Literal, Sequence, Union, cast
 
 from griffe.c3linear import c3linear_merge
-from griffe.docstrings.parsers import Parser, parse
-from griffe.enumerations import Kind, ParameterKind
+from griffe.docstrings.parsers import parse
+from griffe.enumerations import Kind, ParameterKind, Parser
 from griffe.exceptions import AliasResolutionError, BuiltinModuleError, CyclicAliasError, NameResolutionError
 from griffe.expressions import ExprCall, ExprName
 from griffe.logger import get_logger
@@ -203,6 +203,16 @@ class Parameter:
     def __repr__(self) -> str:
         return f"Parameter(name={self.name!r}, annotation={self.annotation!r}, kind={self.kind!r}, default={self.default!r})"
 
+    def __eq__(self, __value: object) -> bool:
+        if not isinstance(__value, Parameter):
+            return NotImplemented
+        return (
+            self.name == __value.name
+            and self.annotation == __value.annotation
+            and self.kind == __value.kind
+            and self.default == __value.default
+        )
+
     @property
     def required(self) -> bool:
         """Whether this parameter is required."""
@@ -751,9 +761,9 @@ class Object(ObjectAliasMixin):
                 },
             )
 
-        if self.lineno:
+        if self.lineno is not None:
             base["lineno"] = self.lineno
-        if self.endlineno:
+        if self.endlineno is not None:
             base["endlineno"] = self.endlineno
         if self.docstring:
             base["docstring"] = self.docstring
@@ -1561,13 +1571,6 @@ class Class(Object):
         try:
             return self.all_members["__init__"].parameters  # type: ignore[union-attr]
         except KeyError:
-            if "dataclass" in self.labels:
-                return Parameters(
-                    *[
-                        Parameter(attr.name, annotation=attr.annotation, default=attr.value)
-                        for attr in self.attributes.values()
-                    ],
-                )
             return Parameters()
 
     @cached_property
