@@ -4,16 +4,18 @@ from __future__ import annotations
 
 import contextlib
 from pathlib import Path
-from typing import Any, Iterable, Iterator
+from typing import TYPE_CHECKING, Any, Iterable, Iterator
 
 from colorama import Fore, Style
 
-from griffe.dataclasses import Alias, Attribute, Class, Function, Object, ParameterKind
-from griffe.enumerations import BreakageKind, ExplanationStyle
+from griffe.enumerations import BreakageKind, ExplanationStyle, ParameterKind
 from griffe.exceptions import AliasResolutionError
 from griffe.git import WORKTREE_PREFIX
 from griffe.logger import get_logger
 
+if TYPE_CHECKING:
+    from griffe.dataclasses import Alias, Attribute, Class, Function, Object
+
 POSITIONAL = frozenset((ParameterKind.positional_only, ParameterKind.positional_or_keyword))
 KEYWORD = frozenset((ParameterKind.keyword_only, ParameterKind.positional_or_keyword))
 POSITIONAL_KEYWORD_ONLY = frozenset((ParameterKind.positional_only, ParameterKind.keyword_only))
@@ -123,7 +125,10 @@ class Breakage:
 
     @property
     def _lineno(self) -> int:
-        if self.kind is BreakageKind.OBJECT_REMOVED:
+        # If the object was removed, and we are able to get the location (file path)
+        # as a relative path, then we use 0 instead of the original line number
+        # (it helps when checking current sources, and avoids pointing to now missing contents).
+        if self.kind is BreakageKind.OBJECT_REMOVED and self._relative_filepath != self._location:
             return 0
         if self.obj.is_alias:
             return self.obj.alias_lineno or 0  # type: ignore[attr-defined]
@@ -502,7 +507,12 @@ def _type_based_yield(
             seen_paths=seen_paths,
         )
     elif old_member.is_class:
-        yield from _class_incompatibilities(old_member, new_member, ignore_private=ignore_private, seen_paths=seen_paths)  # type: ignore[arg-type]
+        yield from _class_incompatibilities(
+            old_member,  # type: ignore[arg-type]
+            new_member,  # type: ignore[arg-type]
+            ignore_private=ignore_private,
+            seen_paths=seen_paths,
+        )
     elif old_member.is_function:
         yield from _function_incompatibilities(old_member, new_member)  # type: ignore[arg-type]
     elif old_member.is_attribute:
