@@ -1,5 +1,6 @@
 """This module exposes objects related to docstrings."""
 
-from griffe.docstrings.parsers import Parser, parse, parsers
+from griffe.docstrings.parsers import parse, parsers
+from griffe.enumerations import Parser
 
 __all__ = ["Parser", "parse", "parsers"]
