@@ -10,6 +10,7 @@ from functools import partial
 from itertools import zip_longest
 from typing import TYPE_CHECKING, Any, Callable, Iterable, Iterator, Sequence
 
+from griffe.agents.nodes import get_parameters
 from griffe.enumerations import ParameterKind
 from griffe.exceptions import NameResolutionError
 from griffe.logger import LogLevel, get_logger
@@ -107,6 +108,16 @@ class Expr:
         """
         yield from ()
 
+    def modernize(self) -> Expr:
+        """Modernize the expression.
+
+        For example, use PEP 604 type unions `|` instead of `typing.Union`.
+
+        Returns:
+            A modernized expression.
+        """
+        return self
+
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:
         """Return the expression as a dictionary.
 
@@ -242,6 +253,11 @@ class ExprCall(Expr):
     arguments: Sequence[str | Expr]
     """Passed arguments."""
 
+    @property
+    def canonical_path(self) -> str:
+        """The canonical path of this subscript's left part."""
+        return self.function.canonical_path
+
     def iterate(self, *, flat: bool = True) -> Iterator[str | Expr]:  # noqa: D102
         yield from _yield(self.function, flat=flat)
         yield "("
@@ -486,8 +502,34 @@ class ExprLambda(Expr):
     """Lambda's body."""
 
     def iterate(self, *, flat: bool = True) -> Iterator[str | Expr]:  # noqa: D102
-        yield "lambda "
-        yield from _join(self.parameters, ", ", flat=flat)
+        pos_only = False
+        pos_or_kw = False
+        kw_only = False
+        length = len(self.parameters)
+        yield "lambda"
+        if length:
+            yield " "
+        for index, parameter in enumerate(self.parameters, 1):
+            if parameter.kind is ParameterKind.positional_only:
+                pos_only = True
+            elif parameter.kind is ParameterKind.var_positional:
+                yield "*"
+            elif parameter.kind is ParameterKind.var_keyword:
+                yield "**"
+            elif parameter.kind is ParameterKind.positional_or_keyword and not pos_or_kw:
+                pos_or_kw = True
+            elif parameter.kind is ParameterKind.keyword_only and not kw_only:
+                kw_only = True
+                yield "*, "
+            if parameter.kind is not ParameterKind.positional_only and pos_only:
+                pos_only = False
+                yield "/, "
+            yield parameter.name
+            if parameter.default and parameter.kind not in (ParameterKind.var_positional, ParameterKind.var_keyword):
+                yield "="
+                yield from _yield(parameter.default, flat=flat)
+            if index < length:
+                yield ", "
         yield ": "
         yield from _yield(self.body, flat=flat)
 
@@ -565,6 +607,41 @@ class ExprName(Expr):
         except NameResolutionError:
             return self.name
 
+    @property
+    def resolved(self) -> Module | Class | None:
+        """The resolved object this name refers to."""
+        try:
+            return self.parent.modules_collection[self.parent.resolve(self.name)]  # type: ignore[union-attr]
+        except Exception:  # noqa: BLE001
+            return self.parent.resolved[self.name]  # type: ignore[union-attr,index]
+
+    @property
+    def is_enum_class(self) -> bool:
+        """Whether this name resolves to an enumeration class."""
+        try:
+            bases = self.resolved.bases  # type: ignore[union-attr]
+        except Exception:  # noqa: BLE001
+            return False
+
+        # TODO: Support inheritance?
+        return any(isinstance(base, Expr) and base.canonical_path == "enum.Enum" for base in bases)
+
+    @property
+    def is_enum_instance(self) -> bool:
+        """Whether this name resolves to an enumeration instance."""
+        try:
+            return self.parent.is_enum_class  # type: ignore[union-attr]
+        except Exception:  # noqa: BLE001
+            return False
+
+    @property
+    def is_enum_value(self) -> bool:
+        """Whether this name resolves to an enumeration value."""
+        try:
+            return self.name == "value" and self.parent.is_enum_instance  # type: ignore[union-attr]
+        except Exception:  # noqa: BLE001
+            return False
+
 
 @dataclass(eq=True, **dataclass_opts)
 class ExprNamedExpr(Expr):
@@ -587,13 +664,13 @@ class ExprNamedExpr(Expr):
 class ExprParameter(Expr):
     """Parameters in function signatures like `a: int = 0`."""
 
-    kind: str
-    """Parameter kind."""
-    name: str | None = None
+    name: str
     """Parameter name."""
+    kind: ParameterKind = ParameterKind.positional_or_keyword
+    """Parameter kind."""
     annotation: Expr | None = None
     """Parameter type."""
-    default: Expr | None = None
+    default: str | Expr | None = None
     """Parameter default."""
 
 
@@ -724,6 +801,18 @@ class ExprYield(Expr):
             yield from _yield(self.value, flat=flat)
 
 
+@dataclass(eq=True, **dataclass_opts)
+class ExprYieldFrom(Expr):
+    """Yield statements like `yield from a`."""
+
+    value: str | Expr
+    """Yielded-from value."""
+
+    def iterate(self, *, flat: bool = True) -> Iterator[str | Expr]:
+        yield "yield from "
+        yield from _yield(self.value, flat=flat)
+
+
 _unary_op_map = {
     ast.Invert: "~",
     ast.Not: "not ",
@@ -912,10 +1001,19 @@ def _build_keyword(node: ast.keyword, parent: Module | Class, function: Expr | N
 
 
 def _build_lambda(node: ast.Lambda, parent: Module | Class, **kwargs: Any) -> Expr:
-    # FIXME: This needs better handling (all parameter kinds).
     return ExprLambda(
-        [ExprParameter(ParameterKind.positional_or_keyword.value, arg.arg) for arg in node.args.args],
-        _build(node.body, parent, **kwargs),
+        parameters=[
+            ExprParameter(
+                name=name,
+                kind=kind,
+                annotation=None,
+                default=default
+                if isinstance(default, str)
+                else safe_get_expression(default, parent=parent, parse_strings=False),
+            )
+            for name, _, kind, default in get_parameters(node.args)
+        ],
+        body=_build(node.body, parent, **kwargs),
     )
 
 
@@ -1002,6 +1100,10 @@ def _build_yield(node: ast.Yield, parent: Module | Class, **kwargs: Any) -> Expr
     return ExprYield(None if node.value is None else _build(node.value, parent, **kwargs))
 
 
+def _build_yield_from(node: ast.YieldFrom, parent: Module | Class, **kwargs: Any) -> Expr:
+    return ExprYieldFrom(_build(node.value, parent, **kwargs))
+
+
 _node_map: dict[type, Callable[[Any, Module | Class], Expr]] = {
     ast.Attribute: _build_attribute,
     ast.BinOp: _build_binop,
@@ -1030,6 +1132,7 @@ _node_map: dict[type, Callable[[Any, Module | Class], Expr]] = {
     ast.Tuple: _build_tuple,
     ast.UnaryOp: _build_unaryop,
     ast.Yield: _build_yield,
+    ast.YieldFrom: _build_yield_from,
 }
 
 # TODO: remove once Python 3.8 support is dropped
